@@ -32,8 +32,10 @@ if ( wp_is_application_passwords_available_for_user( $user_id ) ) {
 }
 
 if ( IS_PROFILE_PAGE ) {
+	// Used in the HTML title tag.
 	$title = __( 'Profile' );
 } else {
+	// Used in the HTML title tag.
 	/* translators: %s: User's display name. */
 	$title = __( 'Edit User %s' );
 }
@@ -551,12 +553,12 @@ endif;
 			/**
 			 * Filters a user contactmethod label.
 			 *
-			 * The dynamic portion of the filter hook, `$name`, refers to
-			 * each of the keys in the contactmethods array.
+			 * The dynamic portion of the hook name, `$name`, refers to
+			 * each of the keys in the contact methods array.
 			 *
 			 * @since 2.9.0
 			 *
-			 * @param string $desc The translatable label for the contactmethod.
+			 * @param string $desc The translatable label for the contact method.
 			 */
 			echo apply_filters( "user_{$name}_label", $desc );
 			?>
@@ -731,11 +733,11 @@ endif;
 
 	</table>
 
-
-		<?php if ( wp_is_application_passwords_available_for_user( $user_id ) ) : ?>
+<?php if ( wp_is_application_passwords_available_for_user( $user_id ) || ! wp_is_application_passwords_supported() ) : // phpcs:disable Generic.WhiteSpace.ScopeIndent ?>
 	<div class="application-passwords hide-if-no-js" id="application-passwords-section">
 		<h2><?php _e( 'Application Passwords' ); ?></h2>
 		<p><?php _e( 'Application passwords allow authentication via non-interactive systems, such as XML-RPC or the REST API, without providing your actual password. Application passwords can be easily revoked. They cannot be used for traditional logins to your website.' ); ?></p>
+		<?php if ( wp_is_application_passwords_available_for_user( $user_id ) ) : ?>
 			<?php
 			if ( is_multisite() ) {
 				$blogs       = get_blogs_of_user( $user_id, true );
@@ -745,10 +747,10 @@ endif;
 					<p>
 						<?php
 						printf(
-							/* translators: 1: URL to my-sites.php, 2: Number of blogs the user has. */
+							/* translators: 1: URL to my-sites.php, 2: Number of sites the user has. */
 							_n(
-								'Application passwords grant access to <a href="%1$s">the %2$s blog in this installation that you have permissions on</a>.',
-								'Application passwords grant access to <a href="%1$s">all %2$s blogs in this installation that you have permissions on</a>.',
+								'Application passwords grant access to <a href="%1$s">the %2$s site in this installation that you have permissions on</a>.',
+								'Application passwords grant access to <a href="%1$s">all %2$s sites in this installation that you have permissions on</a>.',
 								$blogs_count
 							),
 							admin_url( 'my-sites.php' ),
@@ -765,7 +767,7 @@ endif;
 			<div class="create-application-password form-wrap">
 				<div class="form-field">
 					<label for="new_application_password_name"><?php _e( 'New Application Password Name' ); ?></label>
-					<input type="text" size="30" id="new_application_password_name" name="new_application_password_name" placeholder="<?php esc_attr_e( 'WordPress App on My Phone' ); ?>" class="input" aria-required="true" aria-describedby="new_application_password_name_desc" />
+					<input type="text" size="30" id="new_application_password_name" name="new_application_password_name" class="input" aria-required="true" aria-describedby="new_application_password_name_desc" />
 					<p class="description" id="new_application_password_name_desc"><?php _e( 'Required to create an Application Password, but not to update the user.' ); ?></p>
 				</div>
 
@@ -780,7 +782,7 @@ endif;
 				do_action( 'wp_create_application_password_form', $profileuser );
 				?>
 
-				<?php submit_button( __( 'Add New Application Password' ), 'secondary', 'do_new_application_password' ); ?>
+				<button type="button" name="do_new_application_password" id="do_new_application_password" class="button button-secondary"><?php _e( 'Add New Application Password' ); ?></button>
 			</div>
 		<?php } else { ?>
 			<div class="notice notice-error inline">
@@ -795,8 +797,20 @@ endif;
 			$application_passwords_list_table->display();
 			?>
 		</div>
+		<?php elseif ( ! wp_is_application_passwords_supported() ) : ?>
+			<p><?php _e( 'The application password feature requires HTTPS, which is not enabled on this site.' ); ?></p>
+			<p>
+				<?php
+				printf(
+					/* translators: %s: Documentation URL. */
+					__( 'If this is a development website you can <a href="%s" target="_blank">set the environment type accordingly</a> to enable application passwords.' ),
+					__( 'https://wordpress.org/support/article/editing-wp-config-php/#wp_environment_type' )
+				);
+				?>
+			</p>
+		<?php endif; ?>
 	</div>
-<?php endif; ?>
+<?php endif; // phpcs:enable Generic.WhiteSpace.ScopeIndent ?>
 
 		<?php
 		if ( IS_PROFILE_PAGE ) {
